@@ -8,6 +8,6 @@ import tecplot
 
 examples_dir = tecplot.session.tecplot_examples_directory()
 infile = os.path.join(examples_dir, '3D', 'JetSurface.lay')
-outfile = 'jet_surface.png'
+
 tecplot.load_layout(infile)
-tecplot.export_image(outfile)
+tecplot.export.save_jpeg('jet_surface.jpeg', 600)
