@@ -21,4 +21,4 @@ execute_equation('{Nj}={Nj}*10', zones=[current_dataset.zone('right wing'),
 
 # The contour color of the wings in the exported image will now be
 # red, since we have altered the 'Nj' variable by multiplying it by 10.
-tecplot.export_image(outfile)
+tecplot.export.save_png(outfile, 600)
