@@ -39,4 +39,4 @@ plot.legend.show = True
 plot.view.fit()
 
 # save image to file
-tp.export_image('linemap.png')
+tp.export.save_png('linemap.png', 600)
