@@ -8,12 +8,23 @@ from ..exception import *
 
 
 class TextBox(object):
-    """The Box surrounding the `text <Text>` object"""
+    """The Box surrounding the `text <Text>` object
+
+    Warning:
+        `TextBox` objects cannot be created directly. They are returned by the
+        `Text.text_box` read-only property.
+    """
 
     def __init__(self, uid, frame):
         self.uid = uid
         self.frame = frame
 
+    def __str__(self):
+        """Brief string representation"""
+
+        _, text_string = _tecutil.TextGetString(self.uid)
+        return 'Text Box attached to Text "{}"'.format(text_string)
+
     @property
     @annotation_preamble
     def line_thickness(self):
@@ -232,7 +243,13 @@ class TextBox(object):
 
 
 class Text(Annotation):
-    """Text annotation"""
+    """Text annotation
+
+    Warning:
+        `Text` objects cannot be created directly. They are returned by the
+        `Frame.add_text()` method.
+
+    """
 
     def __init__(self, uid, frame):
         super().__init__(uid, frame, Text)
@@ -253,7 +270,7 @@ class Text(Annotation):
             >>> print(frame.add_text('Orange'))
             Text: "Orange"
         """
-        return 'Text: "{}"'.format(self.text_string)
+        return self.text_string
 
     def __eq__(self, other):
         """Checks for `Text` equality in the |Tecplot Engine|.
@@ -300,7 +317,7 @@ class Text(Annotation):
 
     @property
     def text_box(self):
-        """Get the `text box <TextBox>` for this `Text` object.
+        """Get the `TextBox` object for this `Text` object.
 
         The text box is a box that is drawn around the text. Note that
         in order to show the text box, you must set TextBox.type to a value
