@@ -36,7 +36,7 @@ class Array(ctypes.c_void_p):
     @lock()
     def _native_reference(self):
         return _tecutil.DataValueGetReadableNativeRefByUniqueID(
-            self.dataset.uid, self.zone.index+1, self.variable.index+1)
+            self.dataset.uid, self.zone.index + 1, self.variable.index + 1)
 
     def __eq__(self, other):
         return ctypes.addressof(self) == ctypes.addressof(other)
@@ -77,7 +77,7 @@ class Array(ctypes.c_void_p):
     def copy(self, offset=0, size=None):
         size = self.size if size is None else size
         arr = (self.c_type * size)()
-        _tecutil.DataValueArrayGetByRef(self, offset+1, size, arr)
+        _tecutil.DataValueArrayGetByRef(self, offset + 1, size, arr)
         return arr
 
     def _slice_range(self, s):
@@ -199,7 +199,7 @@ class Zone(object):
 
         :type: `Index`
         """
-        return Index(_tecutil.ZoneGetNumByUniqueID(self.uid)-1)
+        return Index(_tecutil.ZoneGetNumByUniqueID(self.uid) - 1)
 
     @property
     def strand(self):
@@ -207,12 +207,12 @@ class Zone(object):
 
         :type: `Index`
         """
-        return Index(_tecutil.ZoneGetStrandID(self.index+1)-1)
+        return Index(_tecutil.ZoneGetStrandID(self.index + 1) - 1)
 
     @strand.setter
     @lock()
     def strand(self, value):
-        _tecutil.ZoneSetStrandID(self.index+1, value+1)
+        _tecutil.ZoneSetStrandID(self.index + 1, value + 1)
 
     @property
     def solution_time(self):
@@ -220,12 +220,12 @@ class Zone(object):
 
         :type: `float`
         """
-        return _tecutil.ZoneGetSolutionTime(self.index+1)
+        return _tecutil.ZoneGetSolutionTime(self.index + 1)
 
     @solution_time.setter
     @lock()
     def solution_time(self, value):
-        _tecutil.ZoneSetSolutionTime(self.index+1, value)
+        _tecutil.ZoneSetSolutionTime(self.index + 1, value)
 
     @property
     def type(self):
@@ -233,7 +233,7 @@ class Zone(object):
 
         :type: `ZoneType`
         """
-        return _tecutil.ZoneGetType(self.index+1)
+        return _tecutil.ZoneGetType(self.index + 1)
 
     @property
     def name(self):
@@ -245,7 +245,7 @@ class Zone(object):
             `TecplotSystemError`
         """
         res, zname = _tecutil.ZoneGetNameByDataSetID(self.dataset.uid,
-                                                     self.index+1)
+                                                     self.index + 1)
         if not res:
             TecplotSystemError()
         return zname
@@ -253,7 +253,7 @@ class Zone(object):
     @name.setter
     @lock()
     def name(self, name):
-        _tecutil.ZoneRenameByDataSetID(self.dataset.uid, self.index+1, name)
+        _tecutil.ZoneRenameByDataSetID(self.dataset.uid, self.index + 1, name)
 
     @property
     def num_variables(self):
@@ -299,7 +299,7 @@ class Zone(object):
     def num_points(self):
         """Number of elements in the associated data array."""
         if self.type is ZoneType.Ordered:
-            return reduce(lambda x, y: x*y,  self.shape, 1)
+            return reduce(lambda x, y: x * y, self.shape, 1)
         else:
             return self.shape[0]
 
@@ -311,7 +311,7 @@ class Zone(object):
             `tuple`(`int`): ``(i,j,k)`` for ordered data or ``(len,)`` for
             unordered data.
         """
-        return _tecutil.ZoneGetIJKByUniqueID(self.dataset.uid, self.index+1)
+        return _tecutil.ZoneGetIJKByUniqueID(self.dataset.uid, self.index + 1)
 
 
 # noinspection PyShadowingNames
@@ -372,7 +372,7 @@ class Variable(object):
             True
         """
         return 'Variable(uid={uid}, dataset={dataset})'.format(
-                uid=self.uid, dataset=repr(self.dataset))
+            uid=self.uid, dataset=repr(self.dataset))
 
     def __eq__(self, other):
         """Checks for equality in the |Tecplot Engine|.
@@ -389,7 +389,7 @@ class Variable(object):
 
         :type: `Index`
         """
-        return Index(_tecutil.VarGetNumByUniqueID(self.uid)-1)
+        return Index(_tecutil.VarGetNumByUniqueID(self.uid) - 1)
 
     @property
     def name(self):
@@ -401,7 +401,7 @@ class Variable(object):
             `TecplotSystemError`
         """
         res, var_name = _tecutil.VarGetNameByDataSetID(self.dataset.uid,
-                                                       self.index+1)
+                                                       self.index + 1)
         if not res:
             TecplotSystemError()
         return var_name
@@ -409,7 +409,7 @@ class Variable(object):
     @name.setter
     @lock()
     def name(self, name):
-        _tecutil.VarRenameByDataSetID(self.dataset.uid, self.index+1, name)
+        _tecutil.VarRenameByDataSetID(self.dataset.uid, self.index + 1, name)
 
     @property
     def num_zones(self):
@@ -458,10 +458,34 @@ class Dataset(object):
             internally to a `Dataset` object.
         frame (`Frame`): A `Frame` to which this `Dataset` is attached.
 
-    A `Dataset` can be shared among several `Frames <Frame>`, though any
-    particular `Dataset` object will have a handle to at least one of them.
-    Any modification of a shared `Dataset` will be reflected in all
-    `Frames <Frame>` that use it.
+    This is the primary data-holding object within the Tecplot Engine. A
+    `Dataset` can be shared among several `Frames <Frame>`, though any
+    particular `Dataset` object will have a handle to at least one of them. Any
+    modification of a shared `Dataset` will be reflected in all `Frames
+    <Frame>` that use it.
+
+    Though a `Dataset` is usually attached to a `Frame` and the plot style
+    associated with that, it can be thought of as independent from any style or
+    plotting representation. Each `Dataset` consists of a list of `Variables
+    <Variable>` which are used by one or more of a list of `Zones <Zone>`. The
+    `Variable` determines the data type while the `Zone` determines the layout
+    such as shape and ordered vs unordered.
+
+    The actual data are found at the intersection of a `Zone` and `Variable`
+    and the resulting object is an `Array`. The data array can be obtained
+    using either path::
+
+        >>> # These two lines obtain the same object "x"
+        >>> x = dataset.zone('My Zone').variable('X')
+        >>> x = dataset.variable('X').zone('My Zone')
+
+    A `Dataset` is the object returned by most data-loading operation in
+    |PyTecplot|::
+
+        >>> dataset = tecplot.data.load_tecplot('my_data.plt')
+
+    Under `Dataset`, there are a number methods to create and delete `zones
+    <Zone>` and `variables <Variable>`.
     """
     def __init__(self, uid, frame):
         self.uid = uid
@@ -542,6 +566,10 @@ class Dataset(object):
 
         Raises:
             `TecplotSystemError`
+
+        Example usage::
+
+            >>> dataset.title = 'My Data'
         """
         try:
             return _tecutil.DataSetGetInfoByUniqueID(self.uid)[0]
@@ -565,6 +593,11 @@ class Dataset(object):
         """Number of `Zones <Zone>` in this `Dataset`.
 
         :type: `integer <int>`
+
+        Example usage::
+
+            >>> for i in range(dataset.num_zones):
+            ...     zone = dataset.zone(i)
         """
         return _tecutil.DataSetGetNumZonesByUniqueID(self.uid)
 
@@ -598,13 +631,24 @@ class Dataset(object):
                 pattern += self.num_zones
             if 0 <= pattern < self.num_zones:
                 with self.frame.activated():
-                    if _tecutil.ZoneIsEnabled(pattern+1):
+                    if _tecutil.ZoneIsEnabled(pattern + 1):
                         return Zone(_tecutil.ZoneGetUniqueIDByDataSetID(
-                                        self.uid, pattern+1), self)
+                                    self.uid, pattern + 1), self)
         raise TecplotIndexError
 
     def zones(self, pattern=None):
-        """Yields all `Zones <Zone>` matching a *pattern*."""
+        """Yields all `Zones <Zone>` matching a *pattern*.
+
+        Parameters:
+            pattern (`string <str>` pattern, optional): `glob-style pattern
+                <fnmatch.fnmatch>` used to match zone names or `None` which
+                will return all zones. (default: `None`)
+
+        Example usage::
+
+            >>> for zone in dataset.zones('A*'):
+            ...     x_array = zone.variable('X')
+        """
         for i in range(self.num_zones):
             try:
                 zone = self.zone(i)
@@ -619,6 +663,11 @@ class Dataset(object):
         """Number of `Variables <Variable>` in this `Dataset`.
 
         :type: `integer <int>`
+
+        Example usage::
+
+            >>> for i in range(dataset.num_variables):
+            ...     variable = dataset.variable(i)
         """
         return _tecutil.DataSetGetNumVarsByUniqueID(self.uid)
 
@@ -651,13 +700,24 @@ class Dataset(object):
             if pattern < 0:
                 pattern += self.num_variables
             if 0 <= pattern < self.num_variables:
-                if _tecutil.VarIsEnabledByDataSetID(self.uid, pattern+1):
+                if _tecutil.VarIsEnabledByDataSetID(self.uid, pattern + 1):
                     return Variable(_tecutil.VarGetUniqueIDByDataSetID(
-                                        self.uid, pattern+1), self)
+                                    self.uid, pattern + 1), self)
         raise TecplotIndexError
 
     def variables(self, pattern=None):
-        """Yields all `Variables <Variable>` matching a *pattern*."""
+        """Yields all `Variables <Variable>` matching a *pattern*.
+
+        Parameters:
+            pattern (`string <str>` pattern, optional): `glob-style pattern
+                <fnmatch.fnmatch>` used to match variable names or `None` which
+                will return all variables. (default: `None`)
+
+        Example usage::
+
+            >>> for variable in dataset.variables('A*'):
+            ...     array = variable.zone('My Zone')
+        """
         for i in range(self.num_variables):
             try:
                 variable = self.variable(i)
@@ -670,7 +730,7 @@ class Dataset(object):
     # noinspection PyPep8Naming
     @property
     def VariablesNamedTuple(self):
-        """This generates a namedtuple object using variable names.
+        """A `collections.namedtuple` object using variable names.
 
         .. note::
 
@@ -684,18 +744,18 @@ class Dataset(object):
         Examples:
 
             This example shows how one can use this n-tuple type with the
-            result from a call to `tecplot.data.probe_at_position`::
+            result from a call to `tecplot.data.query.probe_at_position`::
 
-            >>> from os import path
-            >>> import tecplot as tp
-            >>> examples_dir = tp.session.tecplot_examples_directory()
-            >>> datafile = path.join(examples_dir,'3D_Volume','jetflow.plt')
-            >>> dataset = tp.data.load_tecplot(datafile)
-            >>> result = tp.data.probe_at_position(0,0.1,0.3)
-            >>> data = dataset.VariablesNamedTuple(*result.data)
-            >>> msg = '(RHO, E) = ({:.2f}, {:.2f})'
-            >>> print(msg.format(data.RHO, data.E))
-            (RHO, E) = (1.17, 252930.37)
+                >>> from os import path
+                >>> import tecplot as tp
+                >>> examples_dir = tp.session.tecplot_examples_directory()
+                >>> datafile = path.join(examples_dir,'3D_Volume','jetflow.plt')
+                >>> dataset = tp.data.load_tecplot(datafile)
+                >>> result = tp.data.query.probe_at_position(0,0.1,0.3)
+                >>> data = dataset.VariablesNamedTuple(*result.data)
+                >>> msg = '(RHO, E) = ({:.2f}, {:.2f})'
+                >>> print(msg.format(data.RHO, data.E))
+                (RHO, E) = (1.17, 252930.37)
         """
         names = []
         name_count = {}
@@ -704,7 +764,7 @@ class Dataset(object):
             name = re.sub('\W|^(?=\d)', '_', v.name)
             # prepend Python keywords with underscore
             if iskeyword(name):
-                name = '_'+name
+                name = '_' + name
             if name in name_count:
                 name_count[name] += 1
                 name = '{}{}'.format(name, name_count[name])
@@ -715,11 +775,22 @@ class Dataset(object):
 
     @lock()
     def copy_zones(self, *zones):
-        """Copies `Zones <Zone>` within this `Dataset`."""
+        """Copies `Zones <Zone>` within this `Dataset`.
+
+        Parameters:
+            zones (`Zone`, optional): Specific `zones <Zone>` to copy.
+
+        Returns: `list` of the newly created `Zones <Zone>`.
+
+        Example usage::
+
+            >>> zones = dataset.copy_zones()
+        """
         num_zones = self.num_zones
         with IndexSet(*zones) as zoneset:
             with ArgList(SOURCEZONES=zoneset) as arglist:
-                log.debug(arglist)
+                if __debug__:
+                    log.debug('Zone copy:\n' + str(arglist))
                 _tecutil.ZoneCopyX(arglist)
         return [self.zone(i) for i in range(num_zones, self.num_zones)]
 
@@ -752,7 +823,7 @@ class Dataset(object):
             with ArgList(NAME=name) as arglist:
                 if dtypes is not None:
                     if not hasattr(dtypes, '__iter__'):
-                        dtypes = [dtypes]*dataset.num_zones
+                        dtypes = [dtypes] * dataset.num_zones
                     arglist['VARDATATYPE'] = dtypes
                 if locations is not None:
                     if not hasattr(locations, '__iter__'):
@@ -760,7 +831,7 @@ class Dataset(object):
                     arglist['VALUELOCATION'] = locations
 
                 if __debug__:
-                    msg = 'new variable: '+name
+                    msg = 'new variable: ' + name
                     for k, v in arglist.items():
                         msg += '\n  {} = {}'.format(k, v)
                     log.debug(msg)
@@ -768,11 +839,10 @@ class Dataset(object):
                     raise TecplotSystemError()
             return dataset.variable(new_variable_index)
 
-    # noinspection PyIncorrectDocstring
     @lock()
     def add_zone(self, zone_type, name, shape, dtypes=None, locations=None,
                  **kwargs):
-        """Add a single `Zone` to the active `Dataset`.
+        """Add a single `Zone` to this `Dataset`.
 
         Parameters:
             zone_type (`ZoneType`): The type of `Zone` to be created. Possible
@@ -834,7 +904,7 @@ class Dataset(object):
                                     [dtypes, locations]):
                     if val is not None:
                         if not hasattr(val, '__iter__'):
-                            val = [val]*dataset.num_variables
+                            val = [val] * dataset.num_variables
                         arglist[key] = val
 
                 # ensure floating-point params are floats
@@ -853,7 +923,7 @@ class Dataset(object):
 
                 if __debug__:
                     shp = '({})'.format(','.join(str(s) for s in shape))
-                    msg = 'new dataset shape: '+shp
+                    msg = 'new dataset shape: ' + shp
                     for k, v in arglist.items():
                         msg += '\n  {} = {}'.format(k, v)
                     log.debug(msg)
@@ -903,7 +973,12 @@ class Dataset(object):
             the last `Variable` can not be deleted. This command deletes all
             but the first `Variable` in the `Dataset` (usually ``X``)::
 
-                dataset.delete_variables(dataset.variables())
+                >>> # Try to delete all variables:
+                >>> dataset.delete_variables(dataset.variables())
+                >>> # Dataset requires at least one variable to
+                >>> # exist, so it leaves the first one:
+                >>> print([v.name for v in dataset.variables()])
+                ['X']
         """
         variables = flatten_args(*variables)
         with self.frame.activated():
@@ -954,7 +1029,7 @@ def dataset(frame):
     """
     with frame.activated():
         if not _tecutil.DataSetIsAvailableForFrame(frame.uid):
-            frame.create_dataset(frame.name+' Dataset')
+            frame.create_dataset(frame.name + ' Dataset')
         return Dataset(_tecutil.DataSetGetUniqueID(), frame)
 
 
