@@ -124,14 +124,11 @@ class Frame(object):
     def texts(self):
         """Get an iterator for all `Text` objects in the frame.
 
-        Example usage::
-
-        Get an list of all red `Text` objects.
+        This example shows how to obtain a list of all red `Text` objects::
 
             >>> import tecplot as tp
-            >>> all_red_text_objects = [
-            >>>    T for T in tp.active_frame().texts() if T.color == Color.Red]
-
+            >>> all_red_text_objects = [T for T in tp.active_frame().texts()
+            ...                         if T.color == Color.Red]
         """
         return annotation.Annotation._Iterator(annotation.Text, self)
 
@@ -277,7 +274,7 @@ class Frame(object):
                     raise TecplotSystemError('no Dataset attached to Frame')
                 raise TecplotSystemError(res)
 
-    def plot(self, plot_type=None):
+    def plot(self, plot_type=PlotType.Active):
         """Returns a `Plot` style-control object.
 
         :type:
@@ -300,6 +297,8 @@ class Frame(object):
             >>> plot3d = frame.plot()
             >>> plot3d.show_contour = True
         """
+        if plot_type is PlotType.Active:
+            plot_type = None
         _dispatch = {
             PlotType.Cartesian2D: plot.Cartesian2DFieldPlot,
             PlotType.Cartesian3D: plot.Cartesian3DFieldPlot,
@@ -355,8 +354,8 @@ class Frame(object):
             text (`string <str>`): The text to add to the `Frame`.
                 The text string must have a non-zero length.
             position (`tuple` of `floats <float>` (x,y), optional): The
-                position of the anchor in the specified coordinates. (default:
-                (0,0))
+                position of the anchor as a percentage of the
+                specified coordinates. (default: (0,0))
             coord_sys (`CoordSys`, optional): Coordinate system used to
                 position the anchor of the text object. The possible values
                 are: `CoordSys.Grid` or `CoordSys.Frame`. (default:
