@@ -60,7 +60,7 @@ class ContourColormapOverride(Style):
         contour_override.end_level = 4
 
         # save image to file
-        tp.export_image('cstream_contours.png')
+        tp.export.save_png('cstream_contours.png', 600)
 
     .. figure:: /_static/images/cstream_contours.png
         :width: 300px
@@ -172,7 +172,7 @@ class ContourColormapZebraShade(Style):
         zebra.show = True
         zebra.color = None
 
-        tp.export_image('contour_zebra.png')
+        tp.export.save_png('contour_zebra.png', 600)
 
     .. figure:: /_static/images/contour_zebra.png
         :width: 300px
@@ -264,7 +264,7 @@ class ContourColorCutoff(ContourGroupStyle):
         cutoff.max = 1.0
         cutoff.inverted = True
 
-        tp.export_image('contour_color_cutoff.png')
+        tp.export.save_png('contour_color_cutoff.png', 600)
 
     .. figure:: /_static/images/contour_color_cutoff.png
         :width: 300px
@@ -373,7 +373,7 @@ class ContourColormapFilter(ContourGroupStyle):
         contour_filter.distribution = ColorMapDistribution.Continuous
 
         # save image to file
-        tp.export_image('poly2d_filtered.png')
+        tp.export.save_png('poly2d_filtered.png', 600)
 
     .. figure:: /_static/images/poly2d_filtered.png
         :width: 300px
@@ -539,7 +539,7 @@ class ContourLabels(ContourGroupStyle):
         contour_labels.background_color = Color.White
         contour_labels.margin = 20
 
-        tp.export_image('contour_labels.png')
+        tp.export.save_png('contour_labels.png', 600)
 
     .. figure:: /_static/images/contour_labels.png
         :width: 300px
@@ -770,7 +770,7 @@ class ContourLevels(object):
         levels.reset_levels(np.linspace(55000,115000,61))
 
         # save image to file
-        tp.export_image('3element_adjusted_levels.png')
+        tp.export.save_png('3element_adjusted_levels.png', 600)
 
     .. figure:: /_static/images/3element_adjusted_levels.png
         :width: 300px
@@ -952,7 +952,7 @@ class ContourLines(ContourGroupStyle):
         contour_lines.step = 4
         contour_lines.pattern_length = 2
 
-        tp.export_image('contour_lines.png')
+        tp.export.save_png('contour_lines.png', 600)
 
     .. figure:: /_static/images/contour_lines.png
         :width: 300px
@@ -1062,7 +1062,7 @@ class ContourGroup(Style):
         contour.colormap_name = 'Magma'
 
         # save image to file
-        tp.export_image('polarplot_magma.png')
+        tp.export.save_png('polarplot_magma.png', 600)
 
     .. figure:: /_static/images/polarplot_magma.png
         :width: 300px
