@@ -99,7 +99,7 @@ class FieldmapContour(FieldmapStyle):
         contour.line_color.variable = dataset.variable('R')
 
         # save image to PNG file
-        tp.export_image('fieldmap_contour.png')
+        tp.export.save_png('fieldmap_contour.png', 600)
 
     .. figure:: /_static/images/fieldmap_contour.png
         :width: 300px
@@ -389,7 +389,7 @@ class FieldmapEdge(FieldmapStyle):
             edge.line_thickness = 0.7
 
         # save image to file
-        tp.export_image('fieldmap_edge.png')
+        tp.export.save_png('fieldmap_edge.png', 600)
 
     .. figure:: /_static/images/fieldmap_edge.png
         :width: 300px
@@ -581,7 +581,7 @@ class FieldmapMesh(FieldmapStyle):
             mesh.color = contour
 
         # save image to file
-        tp.export_image('fieldmap_mesh.png')
+        tp.export.save_png('fieldmap_mesh.png', 600)
 
     .. figure:: /_static/images/fieldmap_mesh.png
         :width: 300px
@@ -780,7 +780,7 @@ class FieldmapPoints(FieldmapStyle):
             points.step = (2,2)
 
         # save image to file
-        tp.export_image('fieldmap_points.png')
+        tp.export.save_png('fieldmap_points.png', 600)
 
     .. figure:: /_static/images/fieldmap_points.png
         :width: 300px
@@ -896,7 +896,7 @@ class FieldmapScatter(FieldmapStyle):
         scatter.symbol_type = SymbolType.Geometry
         scatter.fill_color = plot.contour(0)
 
-        tp.export_image('fieldmap_scatter.png')
+        tp.export.save_png('fieldmap_scatter.png', 600)
 
     .. figure:: /_static/images/fieldmap_scatter.png
         :width: 300px
@@ -1133,7 +1133,7 @@ class FieldmapSurfaces(FieldmapStyle):
         fmap.surfaces.j_range = 5,25,10
 
         # save image to file
-        tp.export_image('fieldmap_surfaces_ij.png')
+        tp.export.save_png('fieldmap_surfaces_ij.png', 600)
 
     .. figure:: /_static/images/fieldmap_surfaces_ij.png
         :width: 300px
@@ -1285,7 +1285,7 @@ class FieldmapVector(FieldmapStyle):
         vector.line_thickness = 0.4
 
         # save image to file
-        tp.export_image('fieldmap_vector.png')
+        tp.export.save_png('fieldmap_vector.png', 600)
 
     .. figure:: /_static/images/fieldmap_vector.png
         :width: 300px
@@ -1488,7 +1488,7 @@ class Fieldmap(Style):
         plot.contour(1).colormap_name = 'Sequential - Yellow/Green/Blue'
         plot.contour(1).levels.reset_levels(numpy.linspace(-0.07, 0.07, 50))
 
-        tecplot.export_image('jet_surface_wings.png')
+        tecplot.export.save_png('jet_surface_wings.png', 600)
 
     .. figure:: /_static/images/jet_surface_wings.png
         :width: 300px
@@ -1752,7 +1752,7 @@ class FieldmapEffects3D(FieldmapEffects):
             eff.surface_translucency = 30
 
         # save image to file
-        tp.export_image('fieldmap_effects3d.png')
+        tp.export.save_png('fieldmap_effects3d.png', 600)
 
     .. figure:: /_static/images/fieldmap_effects3d.png
         :width: 300px
@@ -1854,7 +1854,7 @@ class FieldmapShade(FieldmapStyle):
             fmap = plot.fieldmap(zone)
             fmap.shade.color = color
 
-        tecplot.export_image('jet_surface_shade2d.png')
+        tecplot.export.save_png('jet_surface_shade2d.png', 600)
 
     .. figure:: /_static/images/jet_surface_shade2d.png
         :width: 300px
@@ -1932,7 +1932,7 @@ class FieldmapShade3D(FieldmapShade):
             fmap.shade.color = color
             fmap.shade.lighting_effect = False
 
-        tecplot.export_image('jet_surface_shade3d.png')
+        tecplot.export.save_png('jet_surface_shade3d.png', 600)
 
     .. figure:: /_static/images/jet_surface_shade3d.png
         :width: 300px
