@@ -61,7 +61,7 @@ class LinemapBars(LinemapStyle):
         bars.line_color = Color.Red
         bars.line_thickness = 0.01
 
-        tp.export_image('linemap_bars.png')
+        tp.export.save_png('linemap_bars.png', 600)
 
     ..  figure:: /_static/images/linemap_bars.png
         :width: 300px
@@ -223,7 +223,7 @@ class LinemapCurve(LinemapStyle):
         curves[2].spline_derivative_at_ends = 0,0
 
         # save image to file
-        tp.export_image('linemap_curve.png')
+        tp.export.save_png('linemap_curve.png', 600)
 
     ..  figure:: /_static/images/linemap_curve.png
         :width: 300px
@@ -524,7 +524,7 @@ class LinemapErrorBars(LinemapStyle):
 
         plot.view.fit()
 
-        tp.export_image('linemap_error_bars.png')
+        tp.export.save_png('linemap_error_bars.png', 600)
 
     ..  figure:: /_static/images/linemap_error_bars.png
         :width: 300px
@@ -540,8 +540,10 @@ class LinemapErrorBars(LinemapStyle):
 
         :type: `bool`
 
-        The parent plot object must have error bars enables as well::
+        The parent plot object must have error bars enables as well which will
+        require a variable to be set::
 
+            >>> plot.linemap(0).error_bars.variable = dataset.variable('E')
             >>> plot.show_error_bars = True
             >>> plot.linemap(0).error_bars.show = True
         """
@@ -728,7 +730,7 @@ class LinemapIndices(LinemapStyle):
             lmap.indices.i_range = 0,0,3
 
         # save image to file
-        tp.export_image('linemap_indices.png')
+        tp.export.save_png('linemap_indices.png', 600)
 
 
     ..  figure:: /_static/images/linemap_indices.png
@@ -837,7 +839,7 @@ class LinemapLine(LinemapStyle):
         line.pattern_length = 2
 
         # save image to file
-        tp.export_image('linemap_line.png')
+        tp.export.save_png('linemap_line.png', 600)
 
     ..  figure:: /_static/images/linemap_line.png
         :width: 300px
@@ -969,7 +971,7 @@ class LinemapSymbols(LinemapStyle):
             lmap.symbols.fill_color = Color.Azure
 
         # save image to file
-        tp.export_image('linemap_symbols.png')
+        tp.export.save_png('linemap_symbols.png', 600)
 
     ..  figure:: /_static/images/linemap_symbols.png
         :width: 300px
@@ -1211,7 +1213,7 @@ class Linemap(session.Style):
         plot.view.fit()
 
         # save image to file
-        tp.export_image('linemap.png')
+        tp.export.save_png('linemap.png', 600)
 
     ..  figure:: /_static/images/linemap.png
         :width: 300px
@@ -1384,7 +1386,7 @@ class Linemap(session.Style):
 
     @show_in_legend.setter
     def show_in_legend(self, value):
-        self._set_style(LegendShow(value), sv.ASSIGN, sv.SHOWINLEGEND)
+        self._set_style(LegendShow(value or 1), sv.ASSIGN, sv.SHOWINLEGEND)
 
     @property
     def sort_by(self):
@@ -1489,7 +1491,7 @@ class XYLinemap(Linemap):
         lmap.line.color = Color.Blue
         lmap.y_axis.title.color = Color.Blue
 
-        tp.export_image('linemap_xy.png')
+        tp.export.save_png('linemap_xy.png', 600)
 
     ..  figure:: /_static/images/linemap_xy.png
         :width: 300px
