@@ -46,7 +46,7 @@ class SketchPlot(Plot):
         plot.axes.x_axis.show = True
         plot.axes.y_axis.show = True
 
-        tp.export_image('plot_sketch.png')
+        tp.export.save_png('plot_sketch.png', 600)
 
     ..  figure:: /_static/images/plot_sketch.png
         :width: 300px
@@ -101,7 +101,7 @@ class FieldPlot(Plot):
         plot.contour(0).variable = dataset.variable('S')
 
         # save image to file
-        tp.export_image('plot_field.png')
+        tp.export.save_png('plot_field.png', 600)
 
     ..  figure:: /_static/images/plot_field.png
         :width: 300px
@@ -379,7 +379,7 @@ class Cartesian2DFieldPlot(FieldPlot):
         plot.contour(0).colormap_name = 'Sequential - Yellow/Green/Blue'
 
         # save image to file
-        tp.export_image('plot_field2d.png')
+        tp.export.save_png('plot_field2d.png', 600)
 
     ..  figure:: /_static/images/plot_field2d.png
         :width: 300px
@@ -492,7 +492,7 @@ class Cartesian3DFieldPlot(FieldPlot):
         plot.show_streamtraces = False
 
         # save image to file
-        tp.export_image('plot_field3d.png')
+        tp.export.save_png('plot_field3d.png', 600)
 
     ..  figure:: /_static/images/plot_field3d.png
         :width: 300px
@@ -587,7 +587,7 @@ class LinePlot(Plot):
         plot.show_symbols = True
 
         # save image to file
-        tp.export_image('plot_line.png')
+        tp.export.save_png('plot_line.png', 600)
 
     ..  figure:: /_static/images/plot_line.png
         :width: 300px
@@ -777,7 +777,7 @@ class XYLinePlot(LinePlot):
         plot.linemap(0).symbols.fill_color = FillMode.UseLineColor
 
         # save image to file
-        tp.export_image('plot_xyline.png')
+        tp.export.save_png('plot_xyline.png', 600)
 
     ..  figure:: /_static/images/plot_xyline.png
         :width: 300px
@@ -940,7 +940,7 @@ class PolarLinePlot(LinePlot):
 
         plot.view.fit()
 
-        tp.export_image('plot_polar.png')
+        tp.export.save_png('plot_polar.png', 600)
 
     ..  figure:: /_static/images/plot_polar.png
         :width: 300px
