@@ -66,6 +66,7 @@ class _TecInterprocess(object):
             raise TecplotLibraryNotLoadedError(msg)
 
         setlocale(LC_NUMERIC, 'C')
+        os.environ['LC_NUMERIC'] = 'C'
 
         load = {'Darwin': self.load_darwin,
                 'Linux': self.load_linux,
@@ -520,11 +521,11 @@ class _TecInterprocess(object):
         except AttributeError:
             msg = dedent('''
                 Your Tecplot 360 EX Installation may be out-of-date.
-                Please install the latest version of Tecplot 360 EX.''')
-            if self.tecsdkhome:
-                msg += '\nTecplot 360 EX installation found here:'
-                msg += '\n  '+self.tecsdkhome
-            msg += '\nversion: {}'.format(self.sdk_version)
+                Please install the latest version of Tecplot 360 EX.
+                Tecplot 360 EX installation and version:
+                    {}
+                    {}
+                '''.format(self.tecsdkhome or 'Not found!', self.sdk_version))
             raise TecplotInitializationError(msg.replace('\n','\n  '))
 
 _tecinterprocess = _TecInterprocess()
