@@ -523,7 +523,7 @@ class TestFieldmapScatter(unittest.TestCase):
             self.scatter.size = -1
 
     def test_size_by_variable(self):
-        with self.assertRaises(TecplotLogicError):
+        with self.assertRaises((TecplotSystemError, TecplotLogicError)):
             self.scatter.size_by_variable = True
         self.plot.scatter.variable_index = 0
         for c in [True,False,True]:
@@ -546,6 +546,7 @@ class TestFieldmapScatter(unittest.TestCase):
         with self.assertRaises(TecplotSystemError):
             self.scatter.line_thickness = -1
 
+
 class TestFieldmapShade(unittest.TestCase):
     def setUp(self):
         tp.new_layout()
